package net.knarcraft.permissionsigns.listener;

import net.knarcraft.permissionsigns.formatting.StringFormatter;
import net.knarcraft.permissionsigns.formatting.TranslatableMessage;
import net.knarcraft.permissionsigns.manager.SignManager;
import org.bukkit.Material;
import org.bukkit.Tag;
import org.bukkit.block.Block;
import org.bukkit.block.Sign;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.block.BlockBreakEvent;

public class BlockListener implements Listener {

    @EventHandler
    public void onBlockBreak(BlockBreakEvent event) {
        Block block = event.getBlock();
        Player player = event.getPlayer();

        if (event.isCancelled()) {
            return;
        }

        Material material = block.getBlockData().getMaterial();
        if (!Tag.SIGNS.isTagged(material) && !Tag.WALL_SIGNS.isTagged(material)) {
            return;
        }

        Sign sign = (Sign) block.getState();
        boolean registered = SignManager.getSign(sign.getLocation()) != null;
        if (!registered) {
            return;
        }
        if (!player.hasPermission("permissionsigns.admin.create")) {
            event.setCancelled(true);
            player.sendMessage(StringFormatter.getTranslatedErrorMessage(TranslatableMessage.PERMISSION_SIGN_DESTROY_DENY));
        } else {
            SignManager.removeSign(sign.getLocation());
            player.sendMessage(StringFormatter.getTranslatedInfoMessage(TranslatableMessage.PERMISSION_SIGN_REMOVED));
        }

        //TODO: Need to protect against other things that might damage the sign, such as explosions
        //TODO: Only allow the sign to be broken if shift-clicking?
    }

}
